extend_from_adapter_channel

Function extend_from_adapter_channel 

pub fn extend_from_adapter_channel<T: Sample>(
    out_buffer: &mut Vec<T>,
    buffer_in: &dyn Adapter<'_, T>,
    buffer_in_skip: usize,
    buffer_in_channel: usize,
    frames: usize,
) -> usize
Extend the given Vec with the contents of a channel from the given Adapter.

If the adapter does not contain enough frames, then only the available number of frames will be appended to the Vec.

Returns the number of frames that were appended to the Vec.

Panics

  • Panics if buffer_in_channel >= buffer_in.channels()