ResamplerConfig

Struct ResamplerConfig 

pub struct ResamplerConfig {
    pub quality: ResampleQuality,
    pub chunk_size: usize,
    pub sub_chunks: usize,
}
The configuration for a PacketResampler or a Resampler create with resampler_from_quality.

Fields

quality: ResampleQuality

The quality of the resampling algorithm.

By default this is set to ResampleQuality::High.

chunk_size: usize

The chunk size of the resampler. Lower values may reduce latency, but may use more CPU.

By default this is set to 512.

sub_chunks: usize

The number of sub-chunks to use. Higher values may reduce latency, but also may increase CPU usage.

See rubato::Fft::new for more information one what sub_chunks does.

This only has an effect when using the ResampleQuality::High option with the fft-resampler feature enabled.

By default this is set to 1.