pub enum ResampleQuality {
VeryLow,
Low,
High,
HighWithLowLatency,
}Expand description
The quality of the resampling algorithm used for a PacketResampler or a
Resampler created with resampler_from_quality.
Variants
VeryLow
Low quality, low CPU, low latency
Internally this uses the Async resampler from rubato
with linear polynomial interpolation.
Low
Slightly better quality than ResampleQuality::VeryLow, slightly higher
CPU than ResampleQuality::VeryLow, low latency
Internally this uses the Async resampler from rubato
with cubic polynomial interpolation.
High
Great quality, medium CPU, high latency
This is recommended for most non-realtime applications where higher latency is not an issue.
Note, this resampler type adds a significant amount of latency (in the hundreds of frames), so prefer to use the “Low” option if low latency is desired.
If the fft-resampler feature is not enabled, then this will fall
back to ResampleQuality::Low.
Internally this uses the rubato::Fft resampler from rubato.
HighWithLowLatency